Welcome to imbalanced-ensemble documentation! — imbalanced-ensemble 0.1.0 documentation

# Welcome to imbalanced-ensemble documentation!

Date: May 19, 2021 Version: 0.1.0

Imbalanced-ensemble (import as :mod:`imbalanced_ensemble`) is an open source, MIT-licensed Python toolbox for ensemble imbalanced learning. It was built on the basis of scikit-learn and imbalanced-learn.

Getting Started

- Getting Started
  - Background
  - About imbalanced_ensemble
- Install imbalanced_ensemble
  - Prerequisites
  - Installation
    - Install from PyPi
    - Clone from GitHub

API

- `imbalanced_ensemble.ensemble`
  - Under-sampling-based ensembles
  - Over-sampling-based ensembles
  - Reweighting-based ensembles
  - Compatible ensembles
- `imbalanced_ensemble.sampler`
  - Under-sampling Samplers
  - Over-sampling Samplers
- `imbalanced_ensemble.visualizer`
  - Visualizer
- `imbalanced_ensemble.pipeline`
  - Pipeline
- `imbalanced_ensemble.datasets`
  - Datasets
- `imbalanced_ensemble.metrics`
  - Classification Metrics
  - Pairwise Metrics
- `imbalanced_ensemble.utils`
  - Validation checks used in ensembles
  - Validation checks used in samplers

Examples

- Basic usage examples
- Dataset examples
- Evaluation examples
- Pipeline examples

History

- Release History
  - Version 0.1.0 (2021.05)